@@ -4,10 +4,10 @@ version:
 Author: TianyuYuan
 Date: 2021-04-02 15:40:39
 LastEditors: TianyuYuan
-LastEditTime: 2021-04-02 18:49:18
+LastEditTime: 2021-04-02 18:57:37
 '''
 name = "tykit"
-from tykit import (
+from .tykit import (
     pb_range,
     pb_iter,
     pb_multi_thread,
